@@ -9,7 +9,6 @@ import json
 import logging
 import os
 import re
-from typing import Iterable
 import warnings
 
 import fabio
@@ -107,7 +106,7 @@ class EDFTomoScan(TomoScanBase):
         dataset_basename: str | None = None,
         scan_info: dict | None = None,
         n_frames: int | None = None,
-        ignore_projections: Iterable | None = None,
+        ignore_projections: dict | list | tuple | numpy.ndarray | None = None,
     ):
         TomoScanBase.__init__(
             self, scan=scan, type_=self._TYPE, ignore_projections=ignore_projections
