@@ -1,38 +1,11 @@
 # coding: utf-8
-# /*##########################################################################
-#
-# Copyright (c) 2016-2022 European Synchrotron Radiation Facility
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-#
-# ###########################################################################*/
-
-__authors__ = ["H. Payno"]
-__license__ = "MIT"
-__date__ = "04/01/2022"
 
+from __future__ import annotations
 
 import logging
 import os
 import re
 from glob import glob
-from typing import Optional
 
 import fabio
 import numpy
@@ -42,10 +15,16 @@ from tomoscan.framereducer.target import REDUCER_TARGET
 from tomoscan.framereducer.framereducerbase import FrameReducerBase
 from tomoscan.framereducer.method import ReduceMethod
 from tomoscan.scanbase import ReducedFramesInfos, TomoScanBase
+from tomoscan.esrf.scan.utils import get_parameters_frm_par_or_info
 
 _logger = logging.getLogger(__name__)
 
 
+__all__ = [
+    "EDFFrameReducer",
+]
+
+
 class EDFFrameReducer(FrameReducerBase):
     RAW_FLAT_RE = "ref*.*[0-9]{3,4}_[0-9]{3,4}"
     """regular expression to discover flat files"""
@@ -62,7 +41,7 @@ class EDFFrameReducer(FrameReducerBase):
         scan: TomoScanBase,
         reduced_method: ReduceMethod,
         target: REDUCER_TARGET,
-        output_dtype: Optional[numpy.dtype],
+        output_dtype: numpy.dtype | None,
         input_flat_pattern=RAW_FLAT_RE,
         input_dark_pattern=RAW_DARK_RE,
         flat_output_prefix=REFHST_PREFIX,
@@ -124,29 +103,17 @@ class EDFFrameReducer(FrameReducerBase):
                 return None
 
         def parseInfoFile(filePath):
-            def extractInformation(text, alias):
-                text = text.replace(alias, "")
-                text = text.replace("\n", "")
-                text = text.replace(" ", "")
-                text = text.replace("=", "")
-                return _type(text)
+            metadata = get_parameters_frm_par_or_info(filePath)
+            # convert metadata to lower case
+            for alias in info_aliases:
+                if alias in metadata:
+                    return _type(metadata[alias])
+            return None
 
-            info = None
-            f = open(filePath, "r")
-            line = f.readline()
-            while line:
-                for alias in info_aliases:
-                    if alias in line:
-                        info = extractInformation(line, alias)
-                        break
-                line = f.readline()
-            f.close()
-            return info
-
-        info_aliases = [information]
+        info_aliases = [information.lower()]
         if aliases is not None:
             assert type(aliases) in (tuple, list)
-            [info_aliases.append(alias) for alias in aliases]
+            [info_aliases.append(alias.lower()) for alias in aliases]
 
         if not os.path.isdir(scan):
             return None
@@ -324,9 +291,9 @@ class EDFFrameReducer(FrameReducerBase):
 
                 # update electrical machine current
                 if header["SRCUR"] is not None:
-                    if infos.machine_electric_current is None:
-                        infos.machine_electric_current = []
-                    infos.machine_electric_current.append(header["SRCUR"])
+                    if infos.machine_current is None:
+                        infos.machine_current = []
+                    infos.machine_current.append(header["SRCUR"])
                 if header["Count_time"] is not None:
                     if infos.count_time is None:
                         infos.count_time = []
@@ -616,6 +583,9 @@ class EDFFrameReducer(FrameReducerBase):
                 _logger.error(
                     f"Fail to compute regular expresion for {self.input_dark_pattern}"
                 )
+        else:
+            raise ValueError(f"reducer target not handled ({self.reducer_target})")
+
         filelist_fullname = []
         if pattern is None:
             return filelist_fullname
