@@ -154,6 +154,11 @@ class HDF5FrameReducer(FrameReducerBase):
         res = {}
         # res: key is serie index (first serie frame index), value is the numpy.array of the reduced frame
         infos = ReducedFramesInfos()
+        from tomoscan.esrf.scan.nxtomoscan import NXtomoScan  # avoid cyclic import
+
+        if isinstance(self.scan, NXtomoScan):
+            infos.lr_flip = self.scan.detector_is_lr_flip
+            infos.ud_flip = self.scan.detector_is_ud_flip
 
         for series_ in raw_series:
             series_index = min(series_)
