@@ -1,6 +1,13 @@
 import numpy as np
 from silx.io.utils import open as hdf5_open
 
+__all__ = [
+    "get_first_hdf5_entry",
+    "get_h5_value",
+    "get_h5obj_value",
+    "get_hdf5_dataset_shape",
+]
+
 
 def get_first_hdf5_entry(fname):
     with hdf5_open(fname) as fid:
@@ -12,7 +19,7 @@ def get_h5_value(fname, h5_path, default_ret=None):
     with hdf5_open(fname) as fid:
         try:
             val_ptr = fid[h5_path][()]
-            # TODO: look at silx.io.utils.h5py_read_dataset might replace it
+            # TODO: look at silx.io.utils.h5py_read_dataset might replace it. See https://gitlab.esrf.fr/tomotools/tomoscan/-/issues/88
         except KeyError:
             val_ptr = default_ret
     return val_ptr
