@@ -7,15 +7,15 @@ import json
 import logging
 import os
 import pint
-from typing import Iterable
 import h5py
 import numpy
 from silx.io.url import DataUrl
-from silx.io.utils import get_data, h5py_read_dataset
+from silx.io.utils import get_data, h5py_read_dataset, h5py_read_attribute
 from silx.io.utils import open as open_hdf5
 
 from nxtomo.paths.nxtomo import get_paths as _get_nexus_paths
 from nxtomo.utils.transformation import (
+    DetXFlipTransformation,
     DetYFlipTransformation,
     DetZFlipTransformation,
 )
@@ -34,6 +34,7 @@ from tomoscan.esrf.scan.utils import (
     dataset_has_broken_vds,
     check_possible_issue_with_rlimit,
 )
+from tomoscan._CoordinateSystem import CoordinateSystem
 
 
 from .utils import get_compacted_dataslices
@@ -56,20 +57,42 @@ def get_nexus_paths(version: float):
 
 class NXtomoScan(TomoScanBase):
     """
-    This is the implementation of a TomoBase class for an acquisition stored
-    in a HDF5 file. HDF5 may have broken links in virtual layout, considering
-    this the class performs an integrity check on all the links and this
-    can be very long for huge data sets with tens of thousands of links.
-    This check can be set by defining and exportin the shell environment variable
-    TOMOTOOLS_SKIP_DET_CHECK  setted either to 1 or y.
+    This is the class to be used to read an `NXtomo <https://manual.nexusformat.org/classes/applications/NXtomo.html>`_.
 
-    For now several property of the acquisition is accessible thought a getter
-    (like get_scan_range) and a property (scan_range).
+    .. note::
 
-    This is done to be compliant with TomoBase instantiation. But his will be
-    replace progressively by properties at the 'TomoBase' level
+        nxtomo has moved from esrf coordinate system to McStas coordinate.
+        NXtomoScan should absorb this transition.
 
-    :param scan: scan directory or scan masterfile.h5
+        Tomoscan coordinate system is the following:
+
+        .. image:: ../development/img/coordinate_system/coordinate_system_esrf.svg
+            :width: 600 px
+            :align: center
+
+
+        When McStas coordinate system is the following:
+
+        .. image:: ../development/img/coordinate_system/coordinate_system_nexus.svg
+            :width: 600 px
+            :align: center
+
+        .. warning:
+
+            NXtomoScan doesn't handle directly detector frame flips. Detector frame flips can be obtained by :ref:`detector_is_lr_flip` and :ref:`detector_is_ud_flip` must be handled downstream.
+            The flip contained on the NXtomo should be the result of soft and mechanical flips.
+
+
+    .. warning::
+
+        HDF5 may have broken links in virtual layout. By default, this class
+        performs an integrity check on all the links, and this
+        can be very long for huge data sets with tens of thousands of links.
+        This check can be set by defining and export in the shell environment variable
+        TOMOTOOLS_SKIP_DET_CHECK  set either to 1 or y.
+
+
+    :param scan: path to the nexus file.
     :param entry: name of the NXtomo entry to select. If given
                                    index is ignored.
     :param index: of the NXtomo entry to select. Ignored if
@@ -146,7 +169,7 @@ class NXtomoScan(TomoScanBase):
         scan: str | None,
         entry: str = None,
         index: int | None = 0,
-        ignore_projections: dict | Iterable | None = None,
+        ignore_projections: dict | list | tuple | numpy.ndarray | None = None,
         nx_version=None,
     ):
         if entry is not None:
@@ -220,6 +243,7 @@ class NXtomoScan(TomoScanBase):
             "raise_error": False,  # if met an error raise it
             "log_level": logging.WARNING,  # if met an error log it with the following level
         }
+        self.__coordinate_system = None
         # behavior to get when check detector vds
         self._x_flipped = None
         self._y_flipped = None
@@ -417,6 +441,46 @@ class NXtomoScan(TomoScanBase):
             self._nexus_paths = _get_nexus_paths(self.nexus_version)
         return self._nexus_paths
 
+    @property
+    def coordinate_system(self) -> CoordinateSystem | None:
+        """
+        Coordinate system used in the NXtomo file.
+
+        :param default_old_nxtomo: value to return for old nxtomo (<3.0).
+            Before nxtomo 3.0 there was no information about the coordinate system. The ESRF coordinate system was used.
+        :param default: default value for recent nxtomo (>=3.0)
+        """
+        if self.__coordinate_system is None:
+            self.__coordinate_system = self._get_coordinate_system()
+        return self.__coordinate_system
+
+    def _get_coordinate_system(
+        self, default=CoordinateSystem.McStas, default_old_nxtomo=CoordinateSystem.ESRF
+    ) -> CoordinateSystem | None:
+        """
+        return the coordinate system used in the NXtomo file.
+
+        :param default_old_nxtomo: value to return for NXTOMO_VERSION (<2.0. Warning != from the nxtomo project).
+            Before nxtomo 3.0 there was no information about the coordinate system. The ESRF coordinate system was used.
+        :param default: default value for recent nxtomo (>=3.0)
+        """
+        self._check_hdf5scan_validity()
+        with open_hdf5(self.master_file) as h5_file:
+            key = "NeXus_Coordinate_System"
+            if key in h5_file[self._entry].attrs:
+                coordinate_system = h5py_read_attribute(
+                    h5_file[self._entry].attrs, name=key
+                )
+            else:
+                coordinate_system = None
+
+        if coordinate_system is None:
+            if (self.nexus_version or LATEST_NXTOMO_VERSION) < 2.0:
+                return default_old_nxtomo
+            else:
+                return default
+        return CoordinateSystem(coordinate_system)
+
     @property
     @docstring(TomoScanBase.source)
     def source(self):
@@ -613,19 +677,51 @@ class NXtomoScan(TomoScanBase):
 
     @property
     def rotation_angle(self) -> tuple | None:
+        """
+        Return rotation angle (expected counter-clockwise in case we are reading from McStas)
+        """
         cast_to_float = lambda values: [float(val) for val in values]
         return self._get_generic_key(
             "_rotation_angles",
             self.nexus_path.ROTATION_ANGLE_PATH,
             apply_function=cast_to_float,
+            returned_unit=_ureg.degree,
+            default_unit=_ureg.degree,
         )
 
     @property
     def x_translation(self) -> tuple | None:
         cast_to_float = lambda values: [float(val) for val in values]
+        """
+        x translation **according to the esrf coordinate system**
+
+        .. note::
+
+            coordinate system: NXtomo before 1.5 used to be stored within the esrf coordinate system
+
+                       Z axis
+                              ^    Y axis
+                              | /
+            x-ray             |/
+            -------->          ------> X axis
+
+            but Nexus is using the McStas coordinate system
+
+                            Y axis
+                              ^   X axis
+                              |  /
+            x-ray             | /
+            -------->          ------> Z axis
+
+            which is now used by NXtomo (and correctly filled with nxtomomill > 1.2.0dev1)
+        """
+        if self.coordinate_system is CoordinateSystem.McStas:
+            path = self.nexus_path.Z_TRANS_PATH
+        else:
+            path = self.nexus_path.X_TRANS_PATH
         return self._get_generic_key(
             "_x_translations",
-            self.nexus_path.X_TRANS_PATH,
+            path,
             apply_function=cast_to_float,
             returned_unit=_ureg.meter,
             default_unit=_ureg.millimeter,
@@ -633,21 +729,75 @@ class NXtomoScan(TomoScanBase):
 
     @property
     def y_translation(self) -> tuple | None:
-        cast_to_float = lambda values: [float(val) for val in values]
+        """
+        y translation **according to the esrf coordinate system**
+
+        .. note::
+
+            coordinate system: NXtomo before 1.5 used to be stored within the esrf coordinate system
+
+                       Z axis
+                              ^    Y axis
+                              | /
+            x-ray             |/
+            -------->          ------> X axis
+
+            but Nexus is using the McStas coordinate system
+
+                            Y axis
+                              ^   X axis
+                              |  /
+            x-ray             | /
+            -------->          ------> Z axis
+
+            which is now used by NXtomo (and correctly filled with nxtomomill > 1.2.0dev1)
+        """
+        if self.coordinate_system is CoordinateSystem.McStas:
+            path = self.nexus_path.X_TRANS_PATH
+        else:
+            path = self.nexus_path.Y_TRANS_PATH
+
         return self._get_generic_key(
             "_y_translations",
-            self.nexus_path.Y_TRANS_PATH,
-            apply_function=cast_to_float,
+            path,
             returned_unit=_ureg.meter,
             default_unit=_ureg.millimeter,
+            apply_function=lambda values: [float(val) for val in values],
         )
 
     @property
     def z_translation(self) -> tuple | None:
+        """
+        z translation **according to the esrf coordinate system**
+
+        .. note::
+
+            coordinate system: NXtomo before 1.5 used to be stored within the esrf coordinate system
+
+                       Z axis
+                              ^    Y axis
+                              | /
+            x-ray             |/
+            -------->          ------> X axis
+
+            but Nexus is using the McStas coordinate system
+
+                            Y axis
+                              ^   X axis
+                              |  /
+            x-ray             | /
+            -------->          ------> Z axis
+
+            which is now used by NXtomo (and correctly filled with nxtomomill > 1.2.0dev1)
+        """
         cast_to_float = lambda values: [float(val) for val in values]
+        if self.coordinate_system is CoordinateSystem.McStas:
+            path = self.nexus_path.Y_TRANS_PATH
+        else:
+            path = self.nexus_path.Z_TRANS_PATH
         return self._get_generic_key(
             "_z_translations",
-            self.nexus_path.Z_TRANS_PATH,
+            path,
             apply_function=cast_to_float,
             returned_unit=_ureg.meter,
             default_unit=_ureg.millimeter,
@@ -706,14 +856,16 @@ class NXtomoScan(TomoScanBase):
         )
 
     @property
+    @deprecated(
+        replacement="detector_is_lr_flip", since_version="2.2.0", reason="renaming"
+    )
     def x_flipped(self) -> bool:
-        deprecated_warning(
-            type_="property",
-            name="y_flipped",
-            replacement="get_detector_transformations",
-            since_version="1.3",
-        )
-        if self.nexus_path.nx_detector_paths.Y_FLIPPED is not None:
+        return self.detector_is_lr_flip
+
+    @property
+    def detector_is_lr_flip(self) -> bool:
+        if self.nexus_path.nx_detector_paths.X_FLIPPED is not None:
+            # backward compatibily: before NXTransformations was implemented
             return self._get_generic_key(
                 "_x_flipped",
                 "/".join(
@@ -728,24 +880,27 @@ class NXtomoScan(TomoScanBase):
             transformations = self.detector_transformations
             if transformations is None:
                 return None
-            else:
-                # Poor attempt of backward compatibility.
-                # But if there is other transformations then there will be unmanaged.
-                # it was this or raising an error. Will probably raise an Error in short term
+            elif self.coordinate_system is CoordinateSystem.ESRF:
+                # backward compatibily: before NXtomomill 2.0 and nxtomo 3.0 (not matching McStas)
                 return DetZFlipTransformation(flip=True) in transformations
+            elif self.coordinate_system is CoordinateSystem.McStas:
+                return DetYFlipTransformation(flip=True) in transformations
+            else:
+                raise NotImplementedError
         else:
             return None
 
     @property
+    @deprecated(
+        replacement="detector_is_lr_flip", since_version="2.2.0", reason="renaming"
+    )
     def y_flipped(self) -> bool:
-        deprecated_warning(
-            type_="property",
-            name="y_flipped",
-            replacement="get_detector_transformations",
-            since_version="1.3",
-        )
+        return self.detector_is_ud_flip
+
+    @property
+    def detector_is_ud_flip(self) -> bool:
         if self.nexus_path.nx_detector_paths.Y_FLIPPED is not None:
-            # TODO: deprecate ? but replace it by what ?
+            # backward compatibily: before NXTransformations was implemented
             return self._get_generic_key(
                 "_y_flipped",
                 "/".join(
@@ -760,11 +915,10 @@ class NXtomoScan(TomoScanBase):
             transformations = self.detector_transformations
             if transformations is None:
                 return None
-            else:
-                # Poor attempt of backward compatibility.
-                # But if there is other transformations then there will be unmanaged.
-                # it was this or raising an error. Will probably raise an Error in short term
+            elif self.coordinate_system is CoordinateSystem.ESRF:
                 return DetYFlipTransformation(flip=True) in transformations
+            elif self.coordinate_system is CoordinateSystem.McStas:
+                return DetXFlipTransformation(flip=True) in transformations
         else:
             return None
 
@@ -923,8 +1077,8 @@ class NXtomoScan(TomoScanBase):
             self._check_hdf5scan_validity()
             with open_hdf5(self.master_file) as h5_file:
                 if is_attribute and path_key_name in h5_file[self._entry].attrs:
-                    attr_val = h5py_read_dataset(
-                        h5_file[self._entry].attrs[path_key_name]
+                    attr_val = h5py_read_attribute(
+                        h5_file[self._entry].attrs, name=path_key_name
                     )
                     if apply_function is not None:
                         attr_val = apply_function(attr_val)
@@ -934,8 +1088,7 @@ class NXtomoScan(TomoScanBase):
                             h5_file[self._entry][path_key_name],
                             default_unit=default_unit,
                         )
-                        return attr_val.to(returned_unit).magnitude
-
+                        attr_val = attr_val.to(returned_unit).magnitude
                     else:
                         attr_val = h5py_read_dataset(
                             h5_file[self._entry][path_key_name]
@@ -1944,7 +2097,7 @@ class HDF5TomoScan(NXtomoScan):
         scan: str,
         entry: str = None,
         index: int | None = 0,
-        ignore_projections: Iterable | None = None,
+        ignore_projections: dict | list | tuple | numpy.ndarray | None = None,
         nx_version=None,
     ):
         deprecated_warning(
