@@ -900,12 +900,30 @@ def test_save_dark_flat_reduced_several_urls(tmp_path):
 
 
 def test_get_bounding_box(tmp_path):
-    """check bounding box and overlap works"""
+    """
+    check bounding box and overlap works.
+    Warning: the MockNxtomo is using the NXtomo coordinate system ()
+
+                          Z axis
+                             ^    Y axis
+                             | /
+           x-ray             |/
+           -------->          ------> X axis
+
+    When tomoscan coordinate system is the ESRF one
+
+                            Y axis
+                              ^   X axis
+                              |  /
+            x-ray             | /
+            -------->          ------> Z axis
+
+    """
     test_dir = tmp_path / "test_dir"
     test_dir.mkdir()
-    x_pos = 0.0 * _ureg.millimeter
-    y_pos = 1.0 * _ureg.millimeter
-    z_pos = 3.6 * _ureg.millimeter
+    x_pos_nxtomo_coord = 0.0 * _ureg.millimeter
+    y_pos_nxtomo_coord = 1.0 * _ureg.millimeter
+    z_pos_nxtomo_coord = 3.6 * _ureg.millimeter
     magnification = 2
 
     scan = MockNXtomo(
@@ -915,38 +933,38 @@ def test_get_bounding_box(tmp_path):
         distance=1.0,
         energy=1.0,
         magnification=magnification,
-        x_pos=x_pos.magnitude,
-        y_pos=y_pos.magnitude,
-        z_pos=z_pos.magnitude,
+        x_pos=x_pos_nxtomo_coord.magnitude,
+        y_pos=y_pos_nxtomo_coord.magnitude,
+        z_pos=z_pos_nxtomo_coord.magnitude,
     ).scan
 
     pixel_size = MockNXtomo.SAMPLE_PIXEL_SIZE * _ureg.micrometer
     frame_dim = 200
 
     # note: pixel size is provided with magnificaton. To get
-    min_x = x_pos.to(_ureg.meter).magnitude - (
+    min_x_nxtomo_coord = x_pos_nxtomo_coord.to(_ureg.meter).magnitude - (
         frame_dim / 2.0 * pixel_size.to(_ureg.meter).magnitude
     )
-    max_x = x_pos.to(_ureg.meter).magnitude + (
+    max_x_nxtomo_coord = x_pos_nxtomo_coord.to(_ureg.meter).magnitude + (
         frame_dim / 2.0 * pixel_size.to(_ureg.meter).magnitude
     )
-    assert scan.get_bounding_box(axis="x") == (min_x, max_x)
+    assert scan.get_bounding_box(axis="y") == (min_x_nxtomo_coord, max_x_nxtomo_coord)
 
-    min_y = y_pos.to(_ureg.meter).magnitude - (
+    min_y_nxtomo_coord = y_pos_nxtomo_coord.to(_ureg.meter).magnitude - (
         frame_dim / 2.0 * pixel_size.to(_ureg.meter).magnitude
     )
-    max_y = y_pos.to(_ureg.meter).magnitude + (
+    max_y_nxtomo_coord = y_pos_nxtomo_coord.to(_ureg.meter).magnitude + (
         frame_dim / 2.0 * pixel_size.to(_ureg.meter).magnitude
     )
-    assert scan.get_bounding_box(axis="y") == (min_y, max_y)
+    assert scan.get_bounding_box(axis="z") == (min_y_nxtomo_coord, max_y_nxtomo_coord)
 
-    min_z = z_pos.to(_ureg.meter).magnitude - (
+    min_z_nxtomo_coord = z_pos_nxtomo_coord.to(_ureg.meter).magnitude - (
         frame_dim / 2.0 * pixel_size.to(_ureg.meter).magnitude
     )
-    max_z = z_pos.to(_ureg.meter).magnitude + (
+    max_z_nxtomo_coord = z_pos_nxtomo_coord.to(_ureg.meter).magnitude + (
         frame_dim / 2.0 * pixel_size.to(_ureg.meter).magnitude
     )
-    assert scan.get_bounding_box(axis="z") == (min_z, max_z)
+    assert scan.get_bounding_box(axis="x") == (min_z_nxtomo_coord, max_z_nxtomo_coord)
     assert scan.get_bounding_box(axis=None) is not None
 
 
@@ -1039,7 +1057,8 @@ def test_build_drac_metadata(tmp_path):
     nx_tomo = NXtomo().load(
         scan.master_file, "entry", detector_data_as="as_numpy_array"
     )
-    nx_tomo.sample.z_translation = (
+    # warning: the Y on the NXtomo side match the MCStats convention when tomoscan coordinate system is the one used at ESRF.
+    nx_tomo.sample.y_translation = (
         numpy.concatenate(
             (
                 [-1],  # dark frame
@@ -1180,3 +1199,36 @@ def test_pixel_size_getter(tmp_path):
         scan.sample_y_pixel_size
         == nx_tomo.sample.y_pixel_size.to_base_units().magnitude
     )
+
+
+def test_reading_rotation_angle(tmp_path):
+    """
+    Test that NXtomoscan will read angles stored in radians or degree and will always read them in degree
+    Today nxtomo make sure they are savec in degree. But make sure we wil be compatible anyway.
+    """
+    nx_tomo = NXtomo()
+    # test degree
+    angles_degree = numpy.linspace(0.0, 180.0, 100, endpoint=False) * _ureg.degree
+    nx_tomo.sample.rotation_angle = angles_degree
+
+    output_file = tmp_path / "my_nxtomo.nx"
+    entry_name = "entry"
+
+    nx_tomo.save(str(output_file), entry_name)
+
+    scan = NXtomoScan(output_file, entry_name)
+    numpy.testing.assert_almost_equal(scan.rotation_angle, angles_degree.magnitude)
+
+    # test radians
+    # note: nx_tomo always make sure angles are saved in degree
+    nexus_paths = get_nexus_paths(None)
+    nexus_sample_paths = nexus_paths.nx_sample_paths
+
+    rotation_angle_dataset = f"{entry_name}/sample/{nexus_sample_paths.ROTATION_ANGLE}"
+    with h5py.File(output_file, mode="a") as h5f:
+        assert rotation_angle_dataset in h5f
+        h5f[rotation_angle_dataset][()] = angles_degree.to(_ureg.radians).magnitude
+        h5f[rotation_angle_dataset].attrs["units"] = f"{_ureg.radians:~}"
+
+    scan = NXtomoScan(output_file, entry_name)
+    numpy.testing.assert_almost_equal(scan.rotation_angle, angles_degree.magnitude)
