@@ -10,7 +10,6 @@ import os
 import sys
 import psutil
 import warnings
-from typing import Iterable
 import resource
 import traceback
 
@@ -263,21 +262,27 @@ def get_compacted_dataslices(
 @deprecated(
     replacement="tomoscan.serie.from_sequences_to_series", since_version="0.8.0"
 )
-def from_sequences_to_grps(scans: Iterable) -> tuple:
+def from_sequences_to_grps(
+    scans: list[TomoScanBase] | tuple[TomoScanBase, ...] | numpy.ndarray,
+) -> tuple:
     from tomoscan.serie import sequences_to_series_from_sample_name
 
     return sequences_to_series_from_sample_name(scans)
 
 
 @deprecated(replacement="tomoscan.serie.check_serie_is_valid", since_version="0.8.0")
-def check_grp_is_valid(scans: Iterable):
+def check_grp_is_valid(
+    scans: list[TomoScanBase] | tuple[TomoScanBase, ...] | numpy.ndarray,
+):
     from tomoscan.serie import check_series_is_consistent_frm_sample_name
 
     return check_series_is_consistent_frm_sample_name(scans)
 
 
 @deprecated(replacement="tomoscan.serie.serie_is_complete", since_version="0.8.0")
-def grp_is_complete(scans: Iterable) -> bool:
+def grp_is_complete(
+    scans: list[TomoScanBase] | tuple[TomoScanBase, ...] | numpy.ndarray,
+) -> bool:
     from tomoscan.serie import series_is_complete_from_group_size
 
     return series_is_complete_from_group_size(scans)
