@@ -16,6 +16,7 @@ from tomoscan.utils.io import deprecated_warning
 from tomoscan.esrf.identifier.hdf5Identifier import HDF5VolumeIdentifier
 from tomoscan.scanbase import TomoScanBase
 from tomoscan.utils import docstring
+from tomoscan.utils.io import _deprecate_url_in_signature
 from tomoscan.volumebase import VolumeBase, SliceTuple
 
 _logger = logging.getLogger(__name__)
@@ -155,6 +156,7 @@ class HDF5Volume(VolumeBase):
         # to be discussed. Not sure we should raise an error in this case. Could be usefull but this could also be double edged knife
         if self.data is None:
             raise ValueError("No data to be saved")
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if url is None:
             raise ValueError(
@@ -183,7 +185,12 @@ class HDF5Volume(VolumeBase):
 
     @docstring(VolumeBase)
     def data_file_saver_generator(
-        self, n_frames, data_url: DataUrl, overwrite: bool, mode: str = "a", **kwargs
+        self,
+        n_frames,
+        data_url: DataUrl | None = None,
+        overwrite: bool = False,
+        mode: str = "a",
+        **kwargs,
     ):
         """
         warning: the file will be open until the generator exists
@@ -240,6 +247,8 @@ class HDF5Volume(VolumeBase):
                     raise ValueError("item setting only handle ':' for now")
                 _FrameDumper.Dataset[i_frame] = frame  # pylint: disable=E1137
 
+        data_url = data_url or self.data_url
+
         if (
             data_url.file_path() is not None
             and os.path.dirname(data_url.file_path()) != ""
@@ -265,6 +274,7 @@ class HDF5Volume(VolumeBase):
         """
         if self.metadata is None:
             raise ValueError("No metadata to be saved")
+        _deprecate_url_in_signature(url=url)
         url = url or self.metadata_url
         if url is None:
             raise ValueError(
@@ -288,6 +298,7 @@ class HDF5Volume(VolumeBase):
     def load_data(
         self, url: DataUrl | None = None, store: bool = True
     ) -> numpy.ndarray:
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if url is None:
             raise ValueError(
@@ -382,6 +393,7 @@ class HDF5Volume(VolumeBase):
         """
         read from files a couple of slices along any axis.
         """
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         with open_hdf5(filename=url.file_path()) as h5s:
             if url.data_path() in h5s:
@@ -389,6 +401,7 @@ class HDF5Volume(VolumeBase):
 
     @docstring(VolumeBase)
     def load_metadata(self, url: DataUrl | None = None, store: bool = True) -> dict:
+        _deprecate_url_in_signature(url=url)
         url = url or self.metadata_url
         if url is None:
             raise ValueError(
@@ -407,8 +420,9 @@ class HDF5Volume(VolumeBase):
 
     def browse_metadata_files(self, url=None):
         """
-        return a generator go through all the existings files associated to the data volume
+        return a generator go through all the existing files associated to the data volume
         """
+        _deprecate_url_in_signature(url=url)
         url = url or self.metadata_url
         if url is None:
             return
@@ -417,8 +431,9 @@ class HDF5Volume(VolumeBase):
 
     def browse_data_files(self, url=None):
         """
-        return a generator go through all the existings files associated to the data volume
+        return a generator go through all the existing files associated to the data volume
         """
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if url is None:
             return
@@ -426,6 +441,7 @@ class HDF5Volume(VolumeBase):
             yield url.file_path()
 
     def browse_data_urls(self, url=None):
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if url is not None and os.path.exists(url.file_path()):
             yield url
@@ -461,6 +477,7 @@ class HDF5Volume(VolumeBase):
 
     @docstring(VolumeBase)
     def browse_slices(self, url=None):
+        _deprecate_url_in_signature(url=url)
         if url is None and self.data is not None:
             for data_slice in self.data:
                 yield data_slice
@@ -479,6 +496,7 @@ class HDF5Volume(VolumeBase):
 
     @docstring(VolumeBase)
     def load_chunk(self, chunk, url=None):
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if url is None:
             raise ValueError("Cannot get data_url. An url should be provided.")
@@ -489,6 +507,7 @@ class HDF5Volume(VolumeBase):
                 raise KeyError(f"Data path {url.data_path()} not found.")
 
     def get_volume_shape(self, url=None):
+        _deprecate_url_in_signature(url=url)
         if self.data is not None:
             return self.data.shape
         url = url or self.data_url
