@@ -1,7 +1,8 @@
 """module with helper ot save single frame"""
 
+from __future__ import annotations
+
 from tomoscan.esrf.volume.singleframebase import VolumeSingleFrameBase
-from typing import Optional
 
 
 class SingleFrameSaverHelper:
@@ -17,7 +18,7 @@ class SingleFrameSaverHelper:
         volume: VolumeSingleFrameBase,
         data_shape: tuple,
         dtype,
-        cache_size: Optional[int] = None,
+        cache_size: int | None = None,
     ) -> None:
         """
         :param volume: volume to save data for
@@ -60,8 +61,13 @@ class SingleFrameSaverHelper:
             raise RuntimeError(
                 "the helper should be initialized first. Freezing the shape. Please call 'init_saver' before dumping any data to it"
             )
-        if isinstance(index, int):
+        if isinstance(index, slice):
+            # in case we are saving the full frame there is no need for any cache mecanism
+            self._frame_index_to_file[index.start, index.stop, index.step][:] = value
+        elif isinstance(index, (int, tuple)):
             # in case we are saving the full frame there is no need for any cache mecanism
             self._frame_index_to_file[index][:] = value
         else:
-            raise NotImplementedError
+            raise NotImplementedError(
+                f"index is expected to be an instance of int or a tuple of int. Got {type(index)}"
+            )
