@@ -218,6 +218,10 @@ class JP2KVolume(VolumeSingleFrameBase):
         else:
             raise ValueError(f"Scheme {scheme} is not handled")
 
+    def read_file(self, file_name) -> tuple:
+        jp2_file = glymur.Jp2k(file_name)
+        return jp2_file[:]
+
     @staticmethod
     def setup_multithread_encoding(
         n_threads: int | None = None, what_if_not_available: str = "ignore"
