@@ -17,6 +17,7 @@ from silx.io.url import DataUrl
 from tomoscan.esrf.identifier.rawidentifier import RawVolumeIdentifier
 from tomoscan.scanbase import TomoScanBase
 from tomoscan.utils import docstring
+from tomoscan.utils.io import _deprecate_url_in_signature
 from tomoscan.volumebase import VolumeBase
 from tomoscan.io import cast_to_default_types
 
@@ -138,6 +139,7 @@ class RawVolume(VolumeBase):
 
     @docstring(VolumeBase)
     def save_data(self, url: DataUrl | None = None, **kwargs) -> None:
+        _deprecate_url_in_signature(url=url)
         if self.data is None:
             return
         url = url or self.data_url
@@ -179,6 +181,7 @@ class RawVolume(VolumeBase):
 
     @docstring(VolumeBase)
     def load_data(self, url: DataUrl | None = None, store: bool = True) -> numpy.array:
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if url is None:
             raise ValueError(
@@ -229,6 +232,7 @@ class RawVolume(VolumeBase):
         :raises KeyError: if data path already exists and overwrite set to False
         :raises ValueError: if data is None
         """
+        _deprecate_url_in_signature(url=url)
         if self.metadata is None:
             raise ValueError("No metadata to be saved")
         url = url or self.metadata_url
@@ -299,6 +303,7 @@ class RawVolume(VolumeBase):
 
     @docstring(VolumeBase)
     def load_metadata(self, url: DataUrl | None = None, store: bool = True) -> dict:
+        _deprecate_url_in_signature(url=url)
         url = url or self.metadata_url
         if url is None:
             raise ValueError(
@@ -335,6 +340,7 @@ class RawVolume(VolumeBase):
         return metadata
 
     def get_volume_shape(self, url=None):
+        _deprecate_url_in_signature(url=url)
         metadata = self.metadata or self.load_metadata()
         from_metadata = (
             metadata.get("SIZEZ"),
@@ -359,8 +365,9 @@ class RawVolume(VolumeBase):
 
     def browse_metadata_files(self, url=None):
         """
-        return a generator go through all the existings files associated to the data volume
+        return a generator go through all the existing files associated to the data volume
         """
+        _deprecate_url_in_signature(url=url)
         url = url or self.metadata_url
         if url is None:
             return
@@ -369,8 +376,9 @@ class RawVolume(VolumeBase):
 
     def browse_data_files(self, url=None):
         """
-        return a generator go through all the existings files associated to the data volume
+        return a generator go through all the existing files associated to the data volume
         """
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if url is None:
             return
@@ -378,6 +386,7 @@ class RawVolume(VolumeBase):
             yield url.file_path()
 
     def browse_slices(self, url=None):
+        _deprecate_url_in_signature(url=url)
         if url is not None or self.data is None:
             data = self.load_data(url=url)
         else:
@@ -387,13 +396,19 @@ class RawVolume(VolumeBase):
             yield vol_slice
 
     def browse_data_urls(self, url=None):
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if url is not None and os.path.exists(url.file_path()):
             yield url
 
     @docstring(VolumeBase)
     def data_file_saver_generator(
-        self, n_frames, data_url: DataUrl, overwrite: bool, mode: str = "a", **kwargs
+        self,
+        n_frames,
+        data_url: DataUrl | None = None,
+        overwrite: bool = False,
+        mode: str = "a",
+        **kwargs,
     ):
         """
         warning: the file will be open until the generator exists
@@ -422,13 +437,14 @@ class RawVolume(VolumeBase):
                     )
                 value.tofile(self._fid)
 
+        data_url = data_url or self.data_url
         if (
             data_url.file_path() is not None
             and os.path.dirname(data_url.file_path()) != ""
         ):
             os.makedirs(os.path.dirname(data_url.file_path()), exist_ok=True)
 
-        with open(self.data_url.file_path(), "wb") as fid:
+        with open(data_url.file_path(), "wb") as fid:
             for _ in range(n_frames):
                 yield _FrameDumper(fid=fid)
 
