@@ -7,6 +7,7 @@ from __future__ import annotations
 import logging
 import os
 import re
+from warnings import warn
 
 import numpy
 from silx.io.dictdump import dicttoini
@@ -17,6 +18,11 @@ from tomoscan.scanbase import TomoScanBase
 from tomoscan.utils import docstring
 from tomoscan.volumebase import VolumeBase, SliceTuple
 from tomoscan.io import cast_to_default_types
+from tomoscan.utils.io import (
+    deprecated_warning,
+    _deprecate_url_in_signature,
+    catch_log_messages,
+)
 
 _logger = logging.getLogger(__name__)
 
@@ -70,6 +76,7 @@ class VolumeSingleFrameBase(VolumeBase):
             metadata_extension,
         )
         self._start_index = start_index
+        self.write_in_descending_order = False
         self._skip_existing_data_files_removal = False
 
     def get_first_file(self):
@@ -155,6 +162,7 @@ class VolumeSingleFrameBase(VolumeBase):
 
     @docstring(VolumeBase)
     def load_metadata(self, url: DataUrl | None = None, store: bool = True) -> dict:
+        _deprecate_url_in_signature(url=url)
         url = url or self.metadata_url
         if url is None:
             raise ValueError(
@@ -186,6 +194,7 @@ class VolumeSingleFrameBase(VolumeBase):
 
     @docstring(VolumeBase)
     def save_metadata(self, url: DataUrl | None = None) -> None:
+        _deprecate_url_in_signature(url=url)
         if self.metadata is None:
             raise ValueError("No data to be saved")
         url = url or self.metadata_url
@@ -238,6 +247,7 @@ class VolumeSingleFrameBase(VolumeBase):
 
     def remove_existing_data_files(self, url: DataUrl | None = None) -> None:
         """Clean any existing files (if overwrite and rights) that must be used for saving"""
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if not os.path.exists(url.file_path()):
             return
@@ -265,6 +275,7 @@ class VolumeSingleFrameBase(VolumeBase):
 
     @docstring(VolumeBase)
     def save_data(self, url: DataUrl | None = None) -> None:
+        _deprecate_url_in_signature(url=url)
         if self.data is None:
             raise ValueError("No data to be saved")
         url = url or self.data_url
@@ -297,7 +308,10 @@ class VolumeSingleFrameBase(VolumeBase):
         """
         browse output files for n_frames
         """
-        for i_frame in range(n_frames):
+        indices = range(n_frames)
+        if self.write_in_descending_order:
+            indices = list(range(0, -n_frames, -1))
+        for i_frame in indices:
             file_name = self.format_data_path_for_data(
                 data_url.data_path(),
                 index=i_frame,
@@ -307,7 +321,9 @@ class VolumeSingleFrameBase(VolumeBase):
             yield file_name
 
     @docstring(VolumeBase)
-    def data_file_saver_generator(self, n_frames, data_url: DataUrl, overwrite: bool):
+    def data_file_saver_generator(
+        self, n_frames, data_url: DataUrl | None = None, overwrite: bool = False
+    ):
         class _FrameDumper:
             def __init__(self, url_scheme, file_name, callback) -> None:
                 self.url_scheme = url_scheme
@@ -326,6 +342,8 @@ class VolumeSingleFrameBase(VolumeBase):
                     frame=value, file_name=self.file_name, scheme=self.url_scheme
                 )
 
+        # TODO: deprecate `data_url` parameter in the future.
+        data_url = data_url or self.data_url
         os.makedirs(data_url.file_path(), exist_ok=True)
         for file_name in self.data_file_name_generator(
             n_frames=n_frames, data_url=data_url
@@ -337,6 +355,7 @@ class VolumeSingleFrameBase(VolumeBase):
             )
 
     def get_volume_shape(self, url=None):
+        _deprecate_url_in_signature(url=url)
         if self.data is not None:
             return self.data.shape
         else:
@@ -348,6 +367,7 @@ class VolumeSingleFrameBase(VolumeBase):
     def load_data(
         self, url: DataUrl | None = None, store: bool = True
     ) -> numpy.ndarray:
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if url is None:
             raise ValueError(
@@ -370,6 +390,44 @@ class VolumeSingleFrameBase(VolumeBase):
 
         return data
 
+    def _read_frame_from_fast_axis(self, index: int, url: DataUrl) -> numpy.ndarray:
+        """
+        Read a single frame along the 'fast axis' (0 aka Z).
+        Raise "IndexError if not accessible
+        """
+        data_files = tuple(self.browse_data_files())
+        file_path = data_files[index]
+        return self.load_frame(file_name=file_path, scheme=url.scheme())
+
+    def get_slice(
+        self,
+        index: int | str = None,
+        axis=None,
+        xy=None,
+        xz=None,
+        yz=None,
+        url: DataUrl | None = None,
+    ):
+        _deprecate_url_in_signature(url=url)
+        # if we are on the 'fast' read axis then we can directly read a single file. Else we must fall back on the default reading mechanism
+        if axis == 0 or xy is not None:
+            if xy is not None:
+                deprecated_warning(
+                    type_="parameter",
+                    name="xy",
+                    replacement="axis and index",
+                )
+                if axis is None and index is None:
+                    axis = 0
+                    index = xy
+                else:
+                    raise ValueError("several axis (previously xy, xz, yz requested")
+            return self._read_frame_from_fast_axis(
+                index=index, url=(url or self.data_url)
+            )
+        else:
+            return super().get_slice(index=index, axis=axis, xy=xy, xz=xz, yz=yz)
+
     def save_frame(self, frame: numpy.ndarray, file_name: str, scheme: str):
         """
         Function dedicated for volune saving each frame on a single file
@@ -389,8 +447,38 @@ class VolumeSingleFrameBase(VolumeBase):
         """
         raise NotImplementedError("Base class")
 
+    @docstring(VolumeBase)
+    def load_chunk(self, chunk, url=None):
+        if (not numpy.iterable(chunk)) or len(chunk) != 3:
+            raise ValueError(
+                f"Expected 'chunk' to be in the form (slice(start0, stop0), slice(start1, end1), slice(start2, end2)) but got: {chunk}"
+            )
+        url = url or self.data_url
+        scheme = url.scheme() or self.DEFAULT_DATA_SCHEME
+        files = list(self.browse_data_files())
+        files_selection = files[chunk[0]]
+        if files_selection == []:
+            warn(
+                f"load_chunk(): empty files selection returned by chunk={chunk[0]}",
+                RuntimeWarning,
+            )
+            return numpy.array([], dtype="f")
+
+        # Pre-allocate chunk
+        first_frame = self.load_frame(files_selection[0], scheme=scheme)
+        first_frame = first_frame[chunk[1], chunk[2]]
+        result_chunk_shape = (len(files_selection),) + first_frame.shape
+        result_chunk = numpy.zeros(result_chunk_shape, dtype=first_frame.dtype)
+
+        # Browse files, populate chunk
+        for i, filename in enumerate(files_selection):
+            data = self.load_frame(filename, scheme=scheme)
+            result_chunk[i] = data[chunk[1], chunk[2]]
+        return result_chunk
+
     @docstring(VolumeBase)
     def browse_metadata_files(self, url=None):
+        _deprecate_url_in_signature(url=url)
         url = url or self.metadata_url
         if url is None:
             return
@@ -406,6 +494,7 @@ class VolumeSingleFrameBase(VolumeBase):
 
     @docstring(VolumeBase)
     def browse_data_files(self, url=None):
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if url is None:
             return
@@ -433,27 +522,45 @@ class VolumeSingleFrameBase(VolumeBase):
 
     @docstring(VolumeBase)
     def browse_data_urls(self, url=None):
-        url = url or self.data_url
-        for data_file in self.browse_data_files(url=url):
-            yield DataUrl(
-                file_path=data_file,
-                scheme=url.scheme(),
-            )
+        _deprecate_url_in_signature(url=url)
+        url_ = url or self.data_url
+        with catch_log_messages():
+            for data_file in self.browse_data_files(url=url):
+                yield DataUrl(
+                    file_path=data_file,
+                    scheme=url_.scheme(),
+                )
 
     @docstring(VolumeBase)
     def browse_slices(self, url=None):
+        _deprecate_url_in_signature(url=url)
         if url is None and self.data is not None:
             for data_slice in self.data:
                 yield data_slice
         else:
-            url = url or self.data_url
-            if url is None:
+            url_ = url or self.data_url
+            if url_ is None:
                 raise ValueError(
                     "No data and data_url know and no url provided. Unable to browse slices"
                 )
 
-            for file_path in self.browse_data_files(url=url):
-                yield self.load_frame(file_name=file_path, scheme=url.scheme())
+            with catch_log_messages():
+                for file_path in self.browse_data_files(url=url):
+                    yield self.load_frame(file_name=file_path, scheme=url_.scheme())
+
+    @property
+    def write_in_descending_order(self):
+        """
+        Return True if the data is saved with decreasing indices:
+          - data[0] is written to file with index `start_index`
+          - data[1] is written to file with index `start_index - 1`
+          - and so on
+        """
+        return self._write_in_descending_order
+
+    @write_in_descending_order.setter
+    def write_in_descending_order(self, val):
+        self._write_in_descending_order = bool(val)
 
 
 class TIFFLikeDiskAccessor:
