@@ -299,6 +299,40 @@ def test_data_file_saver_generator(tmp_path, volume_constructor):
     )
 
 
+@pytest.mark.parametrize("volume_constructor", volume_constructors)
+def test_decreasing_index(tmp_path, volume_constructor):
+    """
+    Test the 'index_step' parameter
+    """
+    volume_dir = str(tmp_path / "volume")
+    os.makedirs(volume_dir)
+    volume = volume_constructor(folder=volume_dir, start_index=200)
+    volume.write_in_descending_order = True
+    if isinstance(volume, JP2KVolume):
+        volume.rescale_data = False
+    data = numpy.arange(32 * 33 * 34, dtype="f").reshape(
+        (32, 33, 34)
+    )  # put a not-too-small number for jpeg2000
+    volume.data = data
+    volume.save()
+    # Check that the indices are correct (this will not check the write index order)
+    files_list = sorted(
+        glob(os.path.join(volume_dir, f"*.{volume.DEFAULT_DATA_EXTENSION}"))
+    )
+    indices = [
+        int(os.path.splitext(os.path.basename(fname))[0].split("_")[-1])
+        for fname in files_list
+    ]
+    assert sorted(indices, reverse=True) == list(
+        range(volume.start_index, volume.start_index - data.shape[0], -1)
+    )
+
+    # Check that the files order was reversed at write time
+    volume_reader = volume_constructor(folder=volume_dir)
+    data_read = volume_reader.load_data()
+    assert numpy.allclose(data_read, data[::-1, ...])
+
+
 @pytest.mark.parametrize("volume_constructor", volume_constructors)
 def test_several_writer(tmp_path, volume_constructor):
     """
@@ -559,3 +593,32 @@ def test_get_slices(tmp_path, volume_constructor, save_volume_to_file):
         slices_several_axis[(2, 9)],
         slices_axis_2[(2, 9)],
     )
+
+
+@pytest.mark.parametrize("volume_constructor", volume_constructors)
+def test_load_chunk(tmp_path, volume_constructor):
+    volume_dir = str(tmp_path / "volume")
+    os.makedirs(volume_dir)
+    volume = volume_constructor(folder=volume_dir)
+
+    if isinstance(volume, JP2KVolume):  # bis repetita (non) placent
+        volume.rescale_data = False
+    volume.data = numpy.arange(32 * 33 * 34, dtype="f").reshape(
+        (32, 33, 34)
+    )  # put a not-too-small number for jpeg2000
+    volume.save_data()
+
+    volume_reader = volume_constructor(folder=volume_dir)
+    volume_reader.load_data()
+    data_all = volume_reader.data
+
+    chunks_to_test = [
+        (slice(1, 3), slice(None), slice(None)),
+        (slice(-7, None), slice(None), slice(None)),
+        (slice(None), slice(0, 3), slice(None)),
+        (slice(None), slice(None), slice(5, 9)),
+        (slice(None), slice(None), slice(None)),
+    ]
+    for chunk in chunks_to_test:
+        data = volume.load_chunk(chunk)
+        assert numpy.allclose(data, data_all[chunk])
