@@ -20,6 +20,7 @@ from tomoscan.esrf.volume.singleframebase import (
 )
 from tomoscan.scanbase import TomoScanBase
 from tomoscan.utils import docstring, get_subvolume_shape
+from tomoscan.utils.io import _deprecate_url_in_signature, catch_log_messages
 from tomoscan.volumebase import VolumeBase, SliceTuple
 from tomoscan.io import cast_to_default_types
 
@@ -211,6 +212,7 @@ class MultiTIFFVolume(VolumeBase):
             url = DataUrl(file_path=file_path)
         else:
             url = None
+        self._file_path = file_path
         super().__init__(
             url,
             data,
@@ -261,6 +263,7 @@ class MultiTIFFVolume(VolumeBase):
         :raises KeyError: if data path already exists and overwrite set to False
         :raises ValueError: if data is None
         """
+        _deprecate_url_in_signature(url=url)
         # to be discussed. Not sure we should raise an error in this case. Could be useful but this could also be double edged knife
         if self.data is None:
             raise ValueError("No data to be saved")
@@ -291,7 +294,9 @@ class MultiTIFFVolume(VolumeBase):
             raise ValueError(f"Scheme {url.scheme()} is not handled")
 
     @docstring(VolumeBase)
-    def data_file_saver_generator(self, n_frames, data_url: DataUrl, overwrite: bool):
+    def data_file_saver_generator(
+        self, n_frames, data_url: DataUrl | None = None, overwrite: bool = False
+    ):
         """
         warning: the file will be open until the generator exists
         """
@@ -321,6 +326,8 @@ class MultiTIFFVolume(VolumeBase):
                 else:
                     raise ValueError(f"Scheme {self.url.scheme()} is not handled")
 
+        data_url = data_url or self.data_url
+
         for i_frame in range(n_frames):
             yield _FrameDumper(data_url, append=self.append if i_frame == 0 else True)
 
@@ -334,6 +341,7 @@ class MultiTIFFVolume(VolumeBase):
             raise ValueError("No metadata to be saved")
         check_has_tiffle_file("raises")
 
+        _deprecate_url_in_signature(url=url)
         url = url or self.metadata_url
         if url is None:
             raise ValueError(
@@ -352,10 +360,21 @@ class MultiTIFFVolume(VolumeBase):
         else:
             raise ValueError(f"Scheme {url.scheme()} is not handled by multiframe tiff")
 
+    @property
+    def file_path(self):
+        return self._file_path
+
+    @file_path.setter
+    def file_path(self, file_path: str | None):
+        if not (file_path is None or isinstance(file_path, str)):
+            raise TypeError
+        self._file_path = file_path
+
     @docstring(VolumeBase)
     def load_data(
         self, url: DataUrl | None = None, store: bool = True
     ) -> numpy.ndarray:
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if url is None:
             raise ValueError(
@@ -371,6 +390,7 @@ class MultiTIFFVolume(VolumeBase):
 
     @docstring(VolumeBase)
     def load_metadata(self, url: DataUrl | None = None, store: bool = True) -> dict:
+        _deprecate_url_in_signature(url=url)
         url = url or self.metadata_url
         if url is None:
             raise ValueError(
@@ -414,8 +434,9 @@ class MultiTIFFVolume(VolumeBase):
 
     def browse_metadata_files(self, url=None):
         """
-        return a generator go through all the existings files associated to the data volume
+        return a generator go through all the existing files associated to the data volume
         """
+        _deprecate_url_in_signature(url=url)
         url = url or self.metadata_url
         if url is None:
             return
@@ -424,8 +445,9 @@ class MultiTIFFVolume(VolumeBase):
 
     def browse_data_files(self, url=None):
         """
-        return a generator go through all the existings files associated to the data volume
+        return a generator go through all the existing files associated to the data volume
         """
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
         if url is None:
             return
@@ -433,15 +455,18 @@ class MultiTIFFVolume(VolumeBase):
             yield url.file_path()
 
     def browse_data_urls(self, url=None):
+        _deprecate_url_in_signature(url=url)
         url = url or self.data_url
-        for data_file in self.browse_data_files(url=url):
-            yield DataUrl(
-                file_path=data_file,
-                scheme=url.scheme(),
-            )
+        with catch_log_messages():
+            for data_file in self.browse_data_files(url=url):
+                yield DataUrl(
+                    file_path=data_file,
+                    scheme=url.scheme(),
+                )
 
     @docstring(VolumeBase)
     def browse_slices(self, url=None):
+        _deprecate_url_in_signature(url=url)
         if url is None and self.data is not None:
             for data_slice in self.data:
                 yield data_slice
@@ -472,6 +497,7 @@ class MultiTIFFVolume(VolumeBase):
                 )
 
     def get_volume_shape(self, url=None):
+        _deprecate_url_in_signature(url=url)
         if self.data is not None:
             return self.data.shape
         url = url or self.data_url
@@ -490,14 +516,17 @@ class MultiTIFFVolume(VolumeBase):
 
     @docstring(VolumeBase)
     def load_chunk(self, chunk, url=None):
+        _deprecate_url_in_signature(url=url)
         vol_shape = self.get_volume_shape()
         vol_dtype = self._get_tiff_volume_dtype()
         chunk_shape = get_subvolume_shape(chunk, vol_shape)
         data_chunk = numpy.zeros(chunk_shape, dtype=vol_dtype)
         start_z = chunk[0].start or 0
-        for i, image in enumerate(self.browse_slices(url=url)):
-            if i >= start_z and i - start_z < chunk_shape[0]:
-                data_chunk[i - start_z, ...] = image[chunk[1:]]
+
+        with catch_log_messages():
+            for i, image in enumerate(self.browse_slices(url=url)):
+                if i >= start_z and i - start_z < chunk_shape[0]:
+                    data_chunk[i - start_z, ...] = image[chunk[1:]]
         return data_chunk
 
     @staticmethod
