@@ -1,44 +1,16 @@
 # coding: utf-8
-# /*##########################################################################
-#
-# Copyright (c) 2016-2022 European Synchrotron Radiation Facility
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-#
-# ###########################################################################*/
 """utils function for esrf volumes"""
 
-
-__authors__ = [
-    "H. Payno",
-]
-__license__ = "MIT"
-__date__ = "11/07/2022"
-
+from __future__ import annotations
 
 import logging
 import os
-from typing import Optional
 
 import h5py
 from silx.io.utils import open as hdf5_open
 
+from tomoscan.volumebase import SliceTuple
+
 from tomoscan.esrf.identifier.edfidentifier import EDFVolumeIdentifier
 from tomoscan.esrf.identifier.hdf5Identifier import HDF5VolumeIdentifier
 from tomoscan.esrf.identifier.jp2kidentifier import JP2KVolumeIdentifier
@@ -55,6 +27,13 @@ from tomoscan.esrf.volume.tiffvolume import MultiTIFFVolume, TIFFVolume
 
 _logger = logging.getLogger(__name__)
 
+__all__ = [
+    "guess_hdf5_volume_data_paths",
+    "guess_volumes",
+    "get_most_common_extension",
+    "group_slices_by_axis",
+]
+
 _DEFAULT_SCHEME_TO_VOL = {
     EDFVolumeIdentifier.scheme: EDFVolume,
     HDF5VolumeIdentifier.scheme: HDF5Volume,
@@ -69,11 +48,10 @@ def guess_hdf5_volume_data_paths(file_path, data_path="/", depth=3) -> tuple:
     """
     browse hdf5 file 'file_path' from 'data_path' on 'depth' level and check for possible defined volumes.
 
-    :param str file_path: file path to the hdf5 file to browse
-    :param str data_path: path in the file to start research
-    :param int depth: on which layer we should apply research
+    :param file_path: file path to the hdf5 file to browse
+    :param data_path: path in the file to start research
+    :param depth: on which layer we should apply research
     :return: tuple of data_path that could fit a volume
-    :rtype: tuple
     """
     if not h5py.is_hdf5(file_path):
         raise ValueError(f"{file_path} is not a hdf5 file path")
@@ -98,17 +76,16 @@ def guess_hdf5_volume_data_paths(file_path, data_path="/", depth=3) -> tuple:
 
 
 def guess_volumes(
-    path, scheme_to_vol: Optional[dict] = None, filter_histograms=True
+    path, scheme_to_vol: dict | None = None, filter_histograms=True
 ) -> tuple:
     """
     from a file path or a folder path try to guess volume(s)
 
-    :param str path: file or folder path
-    :param dict scheme_to_vol: dict to know which constructor to call. Key if the scheme, value if the volume constructor.
+    :param path: file or folder path
+    :param scheme_to_vol: dict to know which constructor to call. Key if the scheme, value if the volume constructor.
                                usefull for libraries redefining volume or adding some like tomwer.
                                If none provided will take the tomoscan default one
     :return: tuple of volume
-    :rtype: tuple
     """
     if not os.path.exists(path):
         raise OSError("path doesn't exists")
@@ -237,3 +214,26 @@ def _guess_volume_basename(folder_path, extension):
                 f"more than one basename found. Take the most probable one ({sort_basenames[0][0]})"
             )
         return sort_basenames[0][0]
+
+
+def group_slices_by_axis(
+    slices: tuple[SliceTuple], volume_shape: tuple[int] | None
+) -> dict[int, set]:
+    """
+    group a tuple of slices provided as SliceTuple (axis, slice) to a dict.
+    Dict contains predetermined keys (0, 1, 2). For each key with have a set of int (slice indices to be read)
+
+    volume_shape: shape of the reference volume to perform test on slice indices (if provided)
+    """
+    indices_to_read_per_axis: dict[int, set[int]] = {
+        0: set(),
+        1: set(),
+        2: set(),
+    }
+    for slice_ in slices:
+        if volume_shape is not None and (slice_.index >= volume_shape[slice_.axis]):
+            raise IndexError(
+                f"index {slice_.index} is out of bounds for axis {slice_.axis}. (Volume shape is {volume_shape})"
+            )
+        indices_to_read_per_axis[slice_.axis].add(slice_.index)
+    return indices_to_read_per_axis
