@@ -1,35 +1,9 @@
 # coding: utf-8
-# /*##########################################################################
-# Copyright (C) 2016-2022 European Synchrotron Radiation Facility
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-#
-#############################################################################
 """Contains the Factory class and dedicated functions"""
 
-__authors__ = ["H.Payno"]
-__license__ = "MIT"
-__date__ = "27/02/2019"
-
+from __future__ import annotations
 
 import os
-from typing import Union, Optional
 from urllib.parse import urlparse
 
 from tomoscan.esrf.identifier.jp2kidentifier import JP2KVolumeIdentifier
@@ -55,6 +29,10 @@ from .esrf.scan.nxtomoscan import NXtomoScan
 from .scanbase import TomoScanBase
 from nxtomo.application.nxtomo import NXtomo as _NXtomo
 
+__all__ = [
+    "Factory",
+]
+
 
 class Factory:
     """
@@ -63,12 +41,12 @@ class Factory:
 
     @staticmethod
     def create_tomo_object_from_identifier(
-        identifier: Union[str, ScanIdentifier],
+        identifier: str | ScanIdentifier,
     ) -> TomoObject:
         """
         Create an instance of TomoScanBase from his identifier if possible
 
-        :param str identifier: identifier of the TomoScanBase
+        :param identifier: identifier of the TomoScanBase
         :raises: TypeError if identifier is not a str
         :raises: ValueError if identifier cannot be converted back to an instance of TomoScanBase
         """
@@ -160,12 +138,11 @@ class Factory:
             raise ValueError(f"Scheme {scheme} not recognized")
 
     @staticmethod
-    def create_scan_object(scan_path: str, entry: Optional[str] = None) -> TomoScanBase:
+    def create_scan_object(scan_path: str, entry: str | None = None) -> TomoScanBase:
         """
 
-        :param str scan_path: path to the scan directory or file
+        :param scan_path: path to the scan directory or file
         :return: ScanBase instance fitting the scan folder or scan path
-        :rtype: TomoScanBase
         """
         # remove any final separator (otherwise basename might fail)
         scan_path = scan_path.rstrip(os.path.sep)
@@ -180,10 +157,9 @@ class Factory:
     def create_scan_objects(scan_path: str) -> tuple:
         """
 
-        :param str scan_path: path to the scan directory or file
+        :param scan_path: path to the scan directory or file
         :return: all possible instances of TomoScanBase contained in the given
                  path
-        :rtype: tuple
         """
         scan_path = scan_path.rstrip(os.path.sep)
         if EDFTomoScan.is_tomoscan_dir(scan_path):
@@ -206,7 +182,6 @@ class Factory:
 
         :param _dict: dictionary to be converted
         :return: instance of TomoScanBase
-        :rtype: TomoScanBase
         """
         if TomoScanBase.DICT_TYPE_KEY not in _dict:
             raise ValueError(
@@ -224,9 +199,8 @@ class Factory:
     def is_tomoscan_dir(scan_path: str) -> bool:
         """
 
-        :param str scan_path: path to the scan directory or file
+        :param scan_path: path to the scan directory or file
         :return: True if the given path is a root folder of an acquisition.
-        :rtype: bool
         """
         return NXtomoScan.is_tomoscan_dir(scan_path) or EDFTomoScan.is_tomoscan_dir(
             scan_path
