@@ -1,10 +1,14 @@
-from typing import Optional
+from __future__ import annotations
 
 import numpy
-from numpy.core.numerictypes import generic as numy_generic
 from tomoscan.scanbase import TomoScanBase
 from tomoscan.framereducer.method import ReduceMethod
 from tomoscan.framereducer.target import REDUCER_TARGET
+from tomoscan.utils import is_numpy_scalar_dtype
+
+__all__ = [
+    "FrameReducerBase",
+]
 
 
 class FrameReducerBase:
@@ -17,22 +21,22 @@ class FrameReducerBase:
         scan: TomoScanBase,
         reduced_method: ReduceMethod,
         target: REDUCER_TARGET,
-        output_dtype: Optional[numpy.dtype] = None,
+        output_dtype: numpy.dtype | None = None,
         overwrite=False,
     ):
-        self._reduced_method = ReduceMethod.from_value(reduced_method)
+        self._reduced_method = ReduceMethod(reduced_method)
         if not isinstance(scan, TomoScanBase):
             raise TypeError(
                 f"{scan} is expected to be an instance of TomoscanBase not {type(scan)}"
             )
         self._scan = scan
-        self._reducer_target = REDUCER_TARGET.from_value(target)
+        self._reducer_target = REDUCER_TARGET(target)
         if not isinstance(overwrite, bool):
             raise TypeError(
                 f"overwrite is expected to be a boolean not {type(overwrite)}"
             )
         self._overwrite = overwrite
-        if output_dtype is not None and not issubclass(output_dtype, numy_generic):
+        if output_dtype is not None and not is_numpy_scalar_dtype(output_dtype):
             raise TypeError(
                 f"output_dtype is expected to be None or a numpy.dtype, not {type(output_dtype)}"
             )
@@ -55,7 +59,7 @@ class FrameReducerBase:
         return self._overwrite
 
     @property
-    def output_dtype(self) -> Optional[numpy.dtype]:
+    def output_dtype(self) -> numpy.dtype | None:
         return self._output_dtype
 
     def run(self):
