@@ -2,9 +2,11 @@
 
 """Module dedicated to input / output utils"""
 
-from typing import Optional
+from __future__ import annotations
+
 import logging
 import os
+import numpy
 from h5py import File as HDF5File  # noqa F401
 from silx.io.utils import open as hdf5_open
 
@@ -12,8 +14,13 @@ _logger = logging.getLogger(__name__)
 
 _DEFAULT_SWMR_MODE = None
 
+__all__ = [
+    "get_swmr_mode",
+    "check_virtual_sources_exist",
+]
 
-def get_swmr_mode() -> Optional[bool]:
+
+def get_swmr_mode() -> bool | None:
     """
     Return True if the swmr should be used in the tomoools scope
     """
@@ -35,8 +42,8 @@ def check_virtual_sources_exist(fname, data_path):
     """
     Check that a virtual dataset points to actual data.
 
-    :param str fname: HDF5 file path
-    :param str data_path: Path within the HDF5 file
+    :param fname: HDF5 file path
+    :param data_path: Path within the HDF5 file
 
     :return bool res: Whether the virtual dataset points to actual data.
     """
@@ -58,3 +65,28 @@ def check_virtual_sources_exist(fname, data_path):
                 _logger.error(f"Error with virtual source {vsource_fname}")
                 return False
     return True
+
+
+def cast_to_default_types(data: any):
+    """Function that cast non default python types to default python type"""
+    if isinstance(data, dict):
+        # If data is a dictionary, recursively process each value
+        return {key: cast_to_default_types(value) for key, value in data.items()}
+    elif isinstance(data, (list, tuple)):
+        # If data is a list, recursively process each element
+        return [cast_to_default_types(item) for item in data]
+    elif isinstance(data, (numpy.integer, numpy.int_)):
+        # Convert NumPy integers to Python int
+        return int(data)
+    elif isinstance(data, numpy.floating):
+        # Convert NumPy floats to Python float
+        return float(data)
+    elif isinstance(data, numpy.ndarray):
+        # Convert NumPy arrays to list of default python type
+        return data.tolist()
+    elif isinstance(data, numpy.bool):
+        # Convert NumPy booleans to Python bool
+        return bool(data)
+    else:
+        # Return the data as-is if it doesn't match any of the above types
+        return data
