@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 import logging
-import typing
 import numpy
 from .datasetscope import DatasetScope
 from .method import Method
@@ -18,8 +19,8 @@ class _DatasetInfos:
         return self._scope
 
     @scope.setter
-    def scope(self, scope: typing.Union[str, DatasetScope]):
-        self._scope = DatasetScope.from_value(scope)
+    def scope(self, scope: str | DatasetScope):
+        self._scope = DatasetScope(scope)
 
     @property
     def file_path(self):
@@ -58,12 +59,12 @@ class IntensityNormalization:
         return self._method
 
     @method.setter
-    def method(self, method: typing.Union[str, Method, None]):
+    def method(self, method: str | Method | None):
         if method is None:
             method = Method.NONE
-        self._method = Method.from_value(method)
+        self._method = Method(method)
 
-    def set_extra_infos(self, info: typing.Union[dict, _DatasetInfos, _ROIInfo]):
+    def set_extra_infos(self, info: dict | _DatasetInfos | _ROIInfo):
         if info is None:
             self._extra_info = None
         elif not isinstance(info, (_DatasetInfos, _ROIInfo, dict)):
@@ -73,7 +74,7 @@ class IntensityNormalization:
         else:
             self._extra_info = info
 
-    def get_extra_infos(self) -> typing.Union[dict, _DatasetInfos, _ROIInfo]:
+    def get_extra_infos(self) -> dict | _DatasetInfos | _ROIInfo:
         return self._extra_info
 
     def to_dict(self) -> dict:
