@@ -10,7 +10,6 @@ import pathlib
 from bisect import bisect_left
 from collections import OrderedDict
 from math import ceil
-from typing import Iterable
 import warnings
 
 import fabio
@@ -66,7 +65,7 @@ class TomoScanBase(TomoObject):
         self,
         scan: str | None,
         type_: str,
-        ignore_projections: Iterable | None = None,
+        ignore_projections: dict | list | tuple | numpy.ndarray | None = None,
     ):
         super().__init__()
         self.path = scan
@@ -993,25 +992,24 @@ class TomoScanBase(TomoObject):
 
     def flat_field_correction(
         self,
-        projs: Iterable,
-        proj_indexes: Iterable,
+        projs: list | tuple | numpy.ndarray,
+        proj_indexes: list | tuple | numpy.ndarray | None,
         line: int | None = None,
     ):
         """Apply flat field correction on the given data
 
-        :param Iterable projs: list of projection (numpy array) to apply correction
-                              on
-        :param Iterable data proj_indexes: list of indexes of the projection in
-                                         the acquisition sequence. Values can
-                                         be int or None. If None then the
-                                         index take will be the one in the
-                                         middle of the flats taken.
+        :param projs: list, tuple or numpy.ndarray of projections (numpy array) to apply correction on
+        :param proj_indexes: list, tuple or numpy.ndarray of indexes of the projection in
+                             the acquisition sequence. Provide None to use the index in the middle
+                             of the flats taken.
         :param line: index of the line to apply flat filed. If not provided
                      consider we want to apply flat filed on the entire frame
         :return: corrected data: list of numpy array
         """
-        assert isinstance(projs, Iterable)
-        assert isinstance(proj_indexes, Iterable)
+        assert isinstance(projs, (list, tuple, numpy.ndarray))
+        assert proj_indexes is None or isinstance(
+            proj_indexes, (list, tuple, numpy.ndarray)
+        )
         assert isinstance(line, (type(None), int))
 
         def has_missing_keys():
