@@ -1,8 +1,9 @@
-from typing import Union
-from silx.utils.enum import Enum as _Enum
+from __future__ import annotations
+
+from enum import Enum
 
 
-class SourceType(_Enum):
+class SourceType(Enum):
     SPALLATION_NEUTRON = "Spallation Neutron Source"
     PULSED_REACTOR_NEUTRON_SOURCE = "Pulsed Reactor Neutron Source"
     REACTOR_NEUTRON_SOURCE = "Reactor Neutron Source"
@@ -26,25 +27,25 @@ class Source:
         self._type = type
 
     @property
-    def name(self) -> Union[None, str]:
+    def name(self) -> str | None:
         return self._name
 
     @name.setter
-    def name(self, name: Union[str, None]):
+    def name(self, name: str | None):
         if not isinstance(name, (str, type(None))):
             raise TypeError("name is expected to be None or a str")
         self._name = name
 
     @property
-    def type(self) -> Union[None, SourceType]:
+    def type(self) -> SourceType | None:
         return self._type
 
     @type.setter
-    def type(self, type_: Union[None, str, SourceType]):
+    def type(self, type_: str | SourceType | None):
         if type_ is None:
             self._type = None
         else:
-            type_ = SourceType.from_value(type_)
+            type_ = SourceType(type_)
             self._type = type_
 
     def __str__(self):
