@@ -168,7 +168,7 @@ def test_save_load_reduced_darks(tmpdir):
         with pytest.raises(TypeError):
             scan.save_reduced_darks(
                 darks=None,
-                output_urls=(scan.REDUCED_DARKS_DATAURLS,),
+                output_urls=scan.REDUCED_DARKS_DATAURLS,
             )
 
         with pytest.raises(TypeError):
@@ -185,7 +185,7 @@ def test_save_load_reduced_darks(tmpdir):
                 darks={
                     0: numpy.ones((10, 10)),
                 },
-                output_urls=(scan.REDUCED_DARKS_DATAURLS,),
+                output_urls=scan.REDUCED_DARKS_DATAURLS,
             )
 
         with pytest.raises(ValueError):
@@ -193,7 +193,7 @@ def test_save_load_reduced_darks(tmpdir):
                 darks={
                     0: numpy.ones((10, 10)),
                 },
-                output_urls=(scan.REDUCED_DARKS_DATAURLS,),
+                output_urls=scan.REDUCED_DARKS_DATAURLS,
             )
 
 
