@@ -11,7 +11,7 @@ def _docstring(dest, origin):
         try:
             origin = getattr(origin, dest.__name__)
         except AttributeError:
-            raise ValueError("origin class has no %s method" % dest.__name__)
+            raise ValueError(f"origin class has no {dest.__name__} method")
 
     dest.__doc__ = origin.__doc__
     return dest
