@@ -41,7 +41,7 @@ def get_data_sources(fname: str, data_path: str, recursive=True) -> dict:
     Return the nested dict of data_sources.
      Key are (source) file path and keys are identical dict or data_path to the source
 
-    :param bool recursive: If True then go trhough all linked files else won't 'solve' link
+    :param recursive: If True then go trhough all linked files else won't 'solve' link
     """
     with hdf5_open(fname) as f:
         if data_path not in f:
