@@ -1,6 +1,10 @@
 import logging
 import traceback
 import functools
+import os
+import io
+from contextlib import contextmanager
+
 
 depreclog = logging.getLogger("tomoscan.DEPRECATION")
 
@@ -19,18 +23,18 @@ def deprecated_warning(
     """
     Function to log a deprecation warning
 
-    :param str type_: Nature of the object to be deprecated:
+    :param type_: Nature of the object to be deprecated:
         "Module", "Function", "Class" ...
     :param name: Object name.
-    :param str reason: Reason for deprecating this function
+    :param reason: Reason for deprecating this function
         (e.g. "feature no longer provided",
-    :param str replacement: Name of replacement function (if the reason for
+    :param replacement: Name of replacement function (if the reason for
         deprecating was to rename the function)
-    :param str since_version: First *silx* version for which the function was
+    :param since_version: First *silx* version for which the function was
         deprecated (e.g. "0.5.0").
-    :param bool only_once: If true, the deprecation warning will only be
+    :param only_once: If true, the deprecation warning will only be
         generated one time for each different call locations. Default is true.
-    :param int skip_backtrace_count: Amount of last backtrace to ignore when
+    :param skip_backtrace_count: Amount of last backtrace to ignore when
         logging the backtrace
     """
     if not depreclog.isEnabledFor(logging.WARNING):
@@ -69,15 +73,15 @@ def deprecated(
     """
     Decorator that deprecates the use of a function
 
-    :param str reason: Reason for deprecating this function
+    :param reason: Reason for deprecating this function
         (e.g. "feature no longer provided",
-    :param str replacement: Name of replacement function (if the reason for
+    :param replacement: Name of replacement function (if the reason for
         deprecating was to rename the function)
-    :param str since_version: First *silx* version for which the function was
+    :param since_version: First *silx* version for which the function was
         deprecated (e.g. "0.5.0").
-    :param bool only_once: If true, the deprecation warning will only be
+    :param only_once: If true, the deprecation warning will only be
         generated one time. Default is true.
-    :param int skip_backtrace_count: Amount of last backtrace to ignore when
+    :param skip_backtrace_count: Amount of last backtrace to ignore when
         logging the backtrace
     """
 
@@ -100,3 +104,41 @@ def deprecated(
     if func is not None:
         return decorator(func)
     return decorator
+
+
+def filter_esrf_mounting_points(path: str):
+    """
+    filter path like '/mnt/multipath-shares' or '/gpfs/easy'
+    """
+    parts = path.split(os.sep)
+    if len(parts) > 4:
+        if parts[0] == "" and parts[1] in ("gpfs", "mnt") and parts[3] == "data":
+            new_parts = list(parts[0:1]) + list(parts[3:])
+            path = os.sep.join(new_parts)
+    return path
+
+
+def _deprecate_url_in_signature(url, name="url"):
+    if url is None:
+        return
+    deprecated_warning(
+        type_="parameter", name=name, reason="about to be removed", since_version="2.3"
+    )
+
+
+@contextmanager
+def catch_log_messages(logger_name=depreclog.name, level=logging.WARNING):
+    # Create a buffer to capture log messages
+    log_capture = io.StringIO()
+
+    # Get the logger and add a handler to capture messages
+    logger = logging.getLogger(logger_name)
+    handler = logging.StreamHandler(log_capture)
+    handler.setLevel(level)
+    logger.addHandler(handler)
+
+    try:
+        yield log_capture
+    finally:
+        # Clean up: remove the handler
+        logger.removeHandler(handler)
