@@ -27,7 +27,7 @@ def concatenate(output_volume: VolumeBase, volumes: tuple, axis: int) -> None:
 
     :param output_volume VolumeBase: volume to create
     :param tuple volumes: tuple of VolumeBase instances
-    :param int axis: axis to use for doing the concatenation. must be in 0, 1, 2
+    :param axis: axis to use for doing the concatenation. must be in 0, 1, 2
     """
     # 0. do some check
     if not isinstance(output_volume, VolumeBase):
