@@ -1,36 +1,10 @@
 # coding: utf-8
-# /*##########################################################################
-#
-# Copyright (c) 2016-2022 European Synchrotron Radiation Facility
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-#
-# ###########################################################################*/
 """Module containing validators"""
 
-__authors__ = ["H. Payno"]
-__license__ = "MIT"
-__date__ = "24/08/2021"
+from __future__ import annotations
 
 import logging
 import weakref
-from typing import Optional
 
 import numpy
 from silx.io.utils import get_data
@@ -40,6 +14,21 @@ from tomoscan.scanbase import TomoScanBase
 
 _logger = logging.getLogger(__name__)
 
+__all__ = [
+    "ValidatorBase",
+    "DarkEntryValidator",
+    "DarkDatasetValidator",
+    "FlatEntryValidator",
+    "FlatDatasetValidator",
+    "ProjectionEntryValidator",
+    "ProjectionDatasetValidator",
+    "EnergyValidator",
+    "DistanceValidator",
+    "PixelValidator",
+    "BasicScanValidator",
+    "ReconstructionValidator",
+    "is_valid_for_reconstruction",
+]
 
 _VALIDATOR_NAME_TXT_AJUST = 15
 
@@ -47,9 +36,9 @@ _LOCATION_TXT_AJUST = 40
 
 _SCAN_NAME_TXT_AJUST = 30
 
-_BOMB_UCODE = "\U0001f4A3"
+_BOMB_UCODE = "\U0001f4a3"
 
-_EXPLOSION_UCODE = "\U0001f4A5"
+_EXPLOSION_UCODE = "\U0001f4a5"
 
 _THUMB_UP_UCODE = "\U0001f44d"
 
@@ -70,7 +59,7 @@ class ValidatorBase:
 
 
 class _ScanParamValidator(ValidatorBase):
-    def __init__(self, scan: TomoScanBase, name: str, location: Optional[str]):
+    def __init__(self, scan: TomoScanBase, name: str, location: str | None):
         if not isinstance(scan, TomoScanBase):
             raise TypeError(f"{scan} is expected to be an instance of {TomoScanBase}")
         self._scan = weakref.ref(scan)
@@ -106,7 +95,7 @@ class _ScanParamValidator(ValidatorBase):
         raise NotImplementedError("Base class")
 
     @property
-    def scan(self) -> Optional[TomoScanBase]:
+    def scan(self) -> TomoScanBase | None:
         if self._scan and self._scan():
             return self._scan()
         else:
@@ -120,7 +109,7 @@ class _ScanParamValidator(ValidatorBase):
     def clear(self):
         self._valid = None
 
-    def run(self) -> Optional[bool]:
+    def run(self) -> bool | None:
         """
         Return None if unable to find if valid or not. Otherwise a boolean
         """
@@ -261,7 +250,7 @@ class FlatEntryValidator(_ScanParamValidator):
             scan=scan, name="flat(s)", location=scan.get_flat_expected_location()
         )
 
-    def _run(self) -> Optional[bool]:
+    def _run(self) -> bool | None:
         return self.scan.flats is not None and len(self.scan.flats) > 0
 
 
@@ -298,7 +287,7 @@ class ProjectionEntryValidator(_ScanParamValidator):
             location=scan.get_projection_expected_location(),
         )
 
-    def _run(self) -> Optional[bool]:
+    def _run(self) -> bool | None:
         if self.scan.projections is None:
             return False
         elif self.scan.tomo_n is not None:
@@ -338,7 +327,7 @@ class EnergyValidator(_ScanParamValidator):
             location=scan.get_energy_expected_location(),
         )
 
-    def _run(self) -> Optional[bool]:
+    def _run(self) -> bool | None:
         return self.scan.energy not in (None, 0)
 
 
@@ -349,11 +338,11 @@ class DistanceValidator(_ScanParamValidator):
         super().__init__(
             scan=scan,
             name="distance",
-            location=scan.get_distance_expected_location(),
+            location=scan.get_sample_detector_distance_expected_location(),
         )
 
-    def _run(self) -> Optional[bool]:
-        return self.scan.distance not in (None, 0)
+    def _run(self) -> bool | None:
+        return self.scan.sample_detector_distance not in (None, 0)
 
 
 class PixelValidator(_ScanParamValidator):
@@ -366,12 +355,12 @@ class PixelValidator(_ScanParamValidator):
             location=scan.get_pixel_size_expected_location(),
         )
 
-    def _run(self) -> Optional[bool]:
+    def _run(self) -> bool | None:
         from tomoscan.esrf.scan.nxtomoscan import NXtomoScan
 
         if isinstance(self.scan, NXtomoScan):
-            return (self.scan.x_pixel_size not in (None, 0)) and (
-                self.scan.y_pixel_size not in (None, 0)
+            return (self.scan.sample_x_pixel_size not in (None, 0)) and (
+                self.scan.sample_y_pixel_size not in (None, 0)
             )
         else:
             return self.scan.pixel_size not in (None, 0)
@@ -438,7 +427,7 @@ class _ValidatorGroupMixIn:
             valid = valid + validator.is_valid()
         return valid
 
-    def _run(self) -> Optional[bool]:
+    def _run(self) -> bool | None:
         run_ok = True
         for validator in self._validators:
             run_ok = run_ok and validator.run()
@@ -499,7 +488,7 @@ class BasicScanValidator(_ValidatorGroupMixIn, ValidatorBase):
 
 class ReconstructionValidator(BasicScanValidator):
     """
-    Check that a dataset/scan has enought valid parameters to be reconstructed
+    Check that a dataset/scan has enough valid parameters to be reconstructed
     by a software like nabu
     """
 
@@ -541,8 +530,8 @@ def is_valid_for_reconstruction(
     check `scan` contains necessary and valid information to be reconstructed.
 
     :param TomoScanBase scan: scan to be checked
-    :param bool check_values: If true check data for phase retrieval (energy, sample/detector distance...)
-    :param bool check_datasets: open datasets to check for nan values or broken links to file
+    :param check_values: If true check data for phase retrieval (energy, sample/detector distance...)
+    :param check_datasets: open datasets to check for nan values or broken links to file
     """
     checker = ReconstructionValidator(
         scan=scan,
