@@ -13,7 +13,12 @@ from silx.math.combo import (  # pylint: disable=E0611 (not found from the pyx f
     min_max,
 )
 
-from tomoscan.utils.io import deprecated, deprecated_warning
+from tomoscan.utils.io import (
+    deprecated,
+    deprecated_warning,
+    _deprecate_url_in_signature,
+    catch_log_messages,
+)
 from tomoscan.identifier import VolumeIdentifier
 from tomoscan.scanbase import TomoScanBase
 from tomoscan.tomoobject import TomoObject
@@ -150,17 +155,15 @@ class VolumeBase(TomoObject):
         xz=None,
         yz=None,
         url: DataUrl | None = None,
-    ):
+    ) -> None | numpy.ndarray:
         "read a single slice of the volume"
         if xy is yz is xz is axis is None:
             raise ValueError("axis should be provided")
+        _deprecate_url_in_signature(url=url)
 
         if self.data is None:
-            # fixme: must be redefined by inheriting classes.
-            # for example for single base frame we are simply loading the full volume instead of retrieving the
-            # file. This is a bottleneck especially for xy slice because all the files are loaded instead of one
-            # in the worst case.
-            self.load_data(url=url, store=True)
+            with catch_log_messages():
+                self.load_data(url=url, store=True)
 
         if isinstance(index, str):
             if index == "middle":
@@ -215,8 +218,10 @@ class VolumeBase(TomoObject):
         """
         read from files a couple of slices along any axis.
         """
+        _deprecate_url_in_signature(url=url)
 
-        data = self.load_data(url=url, store=False)
+        with catch_log_messages():
+            data = self.load_data(url=url, store=False)
         if data is None:
             raise RuntimeError(
                 f"Enable to load data from disk for {self.get_identifier()}"
@@ -366,7 +371,11 @@ class VolumeBase(TomoObject):
         )
 
     def get_volume_shape(self, url=None) -> tuple:
-        """return volume shape as a tuple"""
+        """
+        return volume shape as a tuple
+
+        :param url: Deprecated
+        """
         raise NotImplementedError("Base class")
 
     def get_bounding_box(self, axis: str | int | None = None):
@@ -436,38 +445,61 @@ class VolumeBase(TomoObject):
         self.load_data(store=True)
 
     def save(self, url: DataUrl | None = None, **kwargs):
-        """save volume data and metadata to disk"""
+        """
+        save volume data and metadata to disk
+
+        :param url: Deprecated
+        """
+        _deprecate_url_in_signature(url=url)
+
         if url is not None:
-            data_url, metadata_url = self.deduce_data_and_metadata_urls(url=url)
+            with catch_log_messages():
+                data_url, metadata_url = self.deduce_data_and_metadata_urls(url=url)
         else:
             data_url = self.data_url
             metadata_url = self.metadata_url
-        self.save_data(data_url, **kwargs)
-        if self.metadata is not None:
-            # a volume is not force to have metadata to save. But calling save_metadata direclty might raise an error
-            # if no metadata found
-            self.save_metadata(metadata_url)
+
+        # catch warning from using data_url until 'url' removed from the signature. See https://gitlab.esrf.fr/tomotools/tomwer/-/issues/1488
+        with catch_log_messages():
+            self.save_data(data_url, **kwargs)
+            if self.metadata is not None:
+                # a volume is not force to have metadata to save. But calling save_metadata direclty might raise an error
+                # if no metadata found
+                self.save_metadata(metadata_url)
 
     def save_data(self, url: DataUrl | None = None, **kwargs) -> None:
         """
         save data to the provided url or existing one if none is provided
+
+        :param url: Deprecated
         """
         raise NotImplementedError("Base class")
 
     def save_metadata(self, url: DataUrl | None = None) -> None:
         """
         save metadata to the provided url or existing one if none is provided
+
+        :param url: Deprecated
         """
         raise NotImplementedError("Base class")
 
     def load_data(
         self, url: DataUrl | None = None, store: bool = True
     ) -> numpy.ndarray:
-        """load volume data from disk"""
+        """
+        Load volume data from disk.
+
+        :param url: Deprecated
+
+        """
         raise NotImplementedError("Base class")
 
     def load_metadata(self, url: DataUrl | None = None, store: bool = True) -> dict:
-        """load volume metadata from disk"""
+        """
+        Load volume metadata from disk
+
+        :param url: Deprecated
+        """
         raise NotImplementedError("Base class")
 
     def check_can_provide_identifier(self):
@@ -544,7 +576,7 @@ class VolumeBase(TomoObject):
 
     def browse_data_files(self, url=None):
         """
-        :param url: data url. If not provided will take self.data_url
+        :param url: **Deprecated** data url. If not provided will take self.data_url
 
         return a generator go through all the existing files associated to the data volume
         """
@@ -552,7 +584,7 @@ class VolumeBase(TomoObject):
 
     def browse_metadata_files(self, url=None):
         """
-        :param url: metadata url. If not provided will take self.metadata_url
+        :param url: **Deprecated** metadata url. If not provided will take self.metadata_url
 
         return a generator go through all the existing files associated to the data volume
         """
@@ -562,7 +594,7 @@ class VolumeBase(TomoObject):
         """
         generator on data urls used.
 
-        :param url: data url to be used. If not provided will take self.data_url
+        :param url: **Deprecated** data url to be used. If not provided will take self.data_url
         """
         raise NotImplementedError("Base class")
 
@@ -570,7 +602,7 @@ class VolumeBase(TomoObject):
         """
         generator of 2D numpy array representing a slice
 
-        :param url: data url to be used. If not provided will browse self.data if exists else self.data_url
+        :param url: **Deprecated** data url to be used. If not provided will browse self.data if exists else self.data_url
         :warning: this will get the slice from the data on disk and never use `data` property.
                   so before browsing slices you might want to check if data is already loaded
         """
@@ -589,14 +621,16 @@ class VolumeBase(TomoObject):
         """
         compute min max over 'data' if exists else browsing the volume slice by slice
 
-        :param url: data url to be used. If not provided will take self.data_url
+        :param url: **Deprecated** data url to be used. If not provided will take self.data_url
         """
+        _deprecate_url_in_signature(url=url)
         min_v = None
         max_v = None
         if self.data is not None:
             data = self.data
         else:
-            data = self.browse_slices(url=url)
+            with catch_log_messages():
+                data = self.browse_slices(url=url)
         for data_slice in data:
             if min_v is None:
                 min_v = data_slice.min()
@@ -607,13 +641,15 @@ class VolumeBase(TomoObject):
                 max_v = max(max_v, max_lv)
         return min_v, max_v
 
-    def data_file_saver_generator(self, n_frames, data_url: DataUrl, overwrite: bool):
+    def data_file_saver_generator(
+        self, n_frames, data_url: DataUrl | None = None, overwrite: bool = False
+    ):
         """
         Provide a helper class to dump data frame by frame. For know the only possible interaction is
         Helper[:] = frame
 
         :param n_frames: number of frame the final volume will contain
-        :param DataUrl data_url: url to dump data
+        :param DataUrl data_url: **Deprecated** url to dump data
         :param overwrite: overwrite existing file ?
         """
         raise NotImplementedError("Base class")
